@@ -4,6 +4,7 @@ use Moose;
 use Devel::REPL;
 use File::HomeDir;
 use File::Spec;
+use vars qw($CURRENT_SCRIPT);
 use namespace::clean -except => [ qw(meta) ];
 
 with 'MooseX::Getopt';
@@ -12,6 +13,10 @@ has 'rcfile' => (
   is => 'ro', isa => 'Str', required => 1, default => sub { 'repl.rc' },
 );
 
+has 'profile' => (
+  is => 'ro', isa => 'Str', required => 1, default => sub { 'Default' },
+);
+
 has '_repl' => (
   is => 'ro', isa => 'Devel::REPL', required => 1,
   default => sub { Devel::REPL->new() }
@@ -19,13 +24,19 @@ has '_repl' => (
 
 sub BUILD {
   my ($self) = @_;
-  $self->load_rcfile;
+  $self->load_profile($self->profile);
+  $self->load_rcfile($self->rcfile);
+}
+
+sub load_profile {
+  my ($self, $profile) = @_;
+  $profile = "Devel::REPL::Profile::${profile}" unless $profile =~ /::/;
+  Class::MOP::load_class($profile);
+  $profile->new->apply_profile($self->_repl);
 }
 
 sub load_rcfile {
-  my ($self) = @_;
-
-  my $rc_file = $self->rcfile;
+  my ($self, $rc_file) = @_;
 
   # plain name => ~/.re.pl/${rc_file}
   if ($rc_file !~ m!/!) {
@@ -43,8 +54,9 @@ sub load_rcfile {
 }
 
 sub eval_rcdata {
-  my $_REPL = $_[0]->_repl;
-  eval $_[1];
+  my ($self, $data) = @_;
+  local $CURRENT_SCRIPT = $self;
+  $self->_repl->eval($data);
 }
 
 sub run {
@@ -58,4 +70,11 @@ sub import {
   $class->new_with_options->run;
 }
 
+sub current {
+  confess "->current should only be called as class method" if ref($_[0]);
+  confess "No current instance (valid only during rc parse)"
+    unless $CURRENT_SCRIPT;
+  return $CURRENT_SCRIPT;
+}
+
 1;
